@@ -26,8 +26,9 @@ DEFAULT_TIMEOUT = 10
 __all__ = ['Error', 'Response', 'BaseAPI', 'API', 'Auth', 'Users', 'Groups',
            'Channels', 'Chat', 'IM', 'IncomingWebhook', 'Search', 'Files',
            'Stars', 'Emoji', 'Presence', 'RTM', 'Team', 'Reactions', 'Pins',
-           'UserGroups', 'UserGroupsUsers', 'MPIM', 'OAuth', 'DND',
-           'FilesComments', 'Reminders', 'Slacker']
+           'UserGroups', 'UserGroupsUsers', 'MPIM', 'OAuth', 'DND', 'Bots',
+           'FilesComments', 'Reminders', 'TeamProfile', 'UsersProfile',
+           'Slacker']
 
 
 class Error(Exception):
@@ -83,7 +84,32 @@ class Auth(BaseAPI):
         return self.get('auth.test')
 
 
+class UsersProfile(BaseAPI):
+    def get(self, user=None, include_labels=False):
+        return super(UsersProfile, self).get(
+            'users.profile.get',
+            params={'user': user, 'include_labels': int(include_labels)}
+        )
+
+    def set(self, user=None, profile=None, name=None, value=None):
+        return self.post('users.profile.get',
+                         data={
+                             'user': user,
+                             'profile': profile,
+                             'name': name,
+                             'value': value
+                         })
+
+
 class Users(BaseAPI):
+    def __init__(self, *args, **kwargs):
+        super(Users, self).__init__(*args, **kwargs)
+        self._profile = UsersProfile(*args, **kwargs)
+
+    @property
+    def profile(self):
+        return self._profile
+
     def info(self, user):
         return self.get('users.info', params={'user': user})
 
@@ -278,7 +304,7 @@ class Chat(BaseAPI):
                              'ts': ts,
                              'text': text,
                              'attachments': attachments,
-                             'parse': None,
+                             'parse': parse,
                              'link_names': int(link_names),
                              'as_user': as_user,
                          })
@@ -456,11 +482,11 @@ class Stars(BaseAPI):
                              'channel': channel,
                              'timestamp': timestamp
                          })
-    
+
     def list(self, user=None, count=None, page=None):
         return self.get('stars.list',
                         params={'user': user, 'count': count, 'page': page})
-    
+
     def remove(self, file_=None, file_comment=None, channel=None, timestamp=None):
         assert file_ or file_comment or channel
 
@@ -498,7 +524,23 @@ class RTM(BaseAPI):
                         })
 
 
+class TeamProfile(BaseAPI):
+    def get(self, visibility=None):
+        return super(TeamProfile, self).get(
+            'users.profile.get',
+            params={'visibility': visibility}
+        )
+
+
 class Team(BaseAPI):
+    def __init__(self, *args, **kwargs):
+        super(Team, self).__init__(*args, **kwargs)
+        self._profile = TeamProfile(*args, **kwargs)
+
+    @property
+    def profile(self):
+        return self._profile
+
     def info(self):
         return self.get('team.info')
 
@@ -742,6 +784,11 @@ class Reminders(BaseAPI):
         return self.get('reminders.list')
 
 
+class Bots(BaseAPI):
+    def info(self, bot=None):
+        return self.get('bots.info', params={'bot': bot})
+
+
 class OAuth(BaseAPI):
     def access(self, client_id, client_secret, code, redirect_uri=None):
         return self.post('oauth.access',
@@ -780,6 +827,7 @@ class Slacker(object):
         self.dnd = DND(token=token, timeout=timeout)
         self.rtm = RTM(token=token, timeout=timeout)
         self.auth = Auth(token=token, timeout=timeout)
+        self.bots = Bots(token=token, timeout=timeout)
         self.chat = Chat(token=token, timeout=timeout)
         self.team = Team(token=token, timeout=timeout)
         self.pins = Pins(token=token, timeout=timeout)
